#
# spec file for package i2pd
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sysuser i2pd
%define sysgroup i2pd
Name:           i2pd
Version:        2.24.0
Release:        1.1
Summary:        C++ implementation of an I2P client
License:        BSD-3-Clause
Group:          Productivity/Networking/System
URL:            http://i2pd.website
Source0:        https://github.com/PurpleI2P/i2pd/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         i2pd-2.19.0-apparmor.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
%if 0%{?suse_version} < 1500
BuildRequires:  boost-devel
%else
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
%endif
BuildRequires:  libminiupnpc-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(zlib)
Suggests:       logrotate
Requires(pre):  shadow
%{?systemd_requires}

%description
The Invisible Internet Protocol (I2P) is a universal anonymous network layer. All
communications over I2P are anonymous and end-to-end encrypted, participants
don't reveal their real IP addresses.

This package contains a C++ implementation of an I2P router.

%prep
%setup -q
%patch0 -p2

cp contrib/debian/i2pd.service i2pd.service.in
cp contrib/debian/i2pd.tmpfile i2pd.tmpfile.in

grep ^User=%{sysuser} i2pd.service.in || { echo '%{sysuser} not found'; exit 1; }
grep ^Group=%{sysgroup} i2pd.service.in || { echo '%{sysgroup} not found'; exit 1; }

sed -i 's/\ \-\-daemon//' i2pd.service.in

%build
pushd build
%cmake \
    -DWITH_LIBRARY=OFF \
    -DWITH_UPNP=ON \
    -DBUILD_SHARED_LIBS=OFF
make -j1
popd

%install
pushd build
%cmake_install
popd

cat debian/%{name}.install | while read _install; do
  ! echo $_install | grep '^%{name}' || continue
  mkdir -p $(echo $_install | sed 's|.*\ \+\(.*\)|%{buildroot}/\1|')
  cp -r $(echo $_install | sed 's|\(\ \+\)|\1%{buildroot}/|')
done

cat debian/%{name}.links | while read _links; do
  mkdir -p $(echo $_links | sed 's|.*\ \+\(.*\)/.*|%{buildroot}/\1|')
  ln -s $(echo $_links | sed 's|\(.*\ \+\)|/\1%{buildroot}/|')
done

install -Dm0644 %{name}.service.in %{buildroot}%{_unitdir}/%{name}.service
install -Dm0644 %{name}.tmpfile.in %{buildroot}%{_tmpfilesdir}/%{name}.conf

install -Dm0644 debian/%{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -Dm0644 {debian,%{buildroot}%{_mandir}/man1}/%{name}.1

install -d %{buildroot}%{_sbindir}
mv %{buildroot}{%{_bindir},%{_sbindir}}/%{name}

find %{buildroot} -regex ".*\(\.a\|\/src\|LICENSE\)" -exec rm -Rf '{}' +

%pre
%service_add_pre %{name}.service
getent group %{sysgroup} >/dev/null || groupadd -r %{sysgroup}
if ! getent passwd %{sysuser} >/dev/null; then
    useradd -r -g %{sysgroup} -d %{_localstatedir}/lib/i2pd -s /sbin/nologin -c "user for i2pd" %{sysuser}
fi
exit 0

%post
%service_add_post %{name}.service
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc ChangeLog LICENSE README.md
%{_sbindir}/i2pd
%dir %{_sysconfdir}/apparmor.d
%config %{_sysconfdir}/apparmor.d/usr.sbin.i2pd
%config %{_sysconfdir}/logrotate.d/i2pd
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_mandir}/man?/i2pd.?%{ext_man}
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_datadir}/i2pd
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_datadir}/i2pd/certificates
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_datadir}/i2pd/certificates/family
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_datadir}/i2pd/certificates/reseed
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_datadir}/i2pd/certificates/router
%{_datadir}/i2pd/certificates/family/
%{_datadir}/i2pd/certificates/reseed/
%{_datadir}/i2pd/certificates/router/
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_localstatedir}/lib/i2pd
%{_localstatedir}/lib/i2pd/
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_sysconfdir}/i2pd
%attr(0750,%{sysuser},%{sysgroup}) %dir %{_sysconfdir}/i2pd/tunnels.conf.d
%config(noreplace) %{_sysconfdir}/i2pd/i2pd.conf
%config(noreplace) %{_sysconfdir}/i2pd/subscriptions.txt
%config(noreplace) %{_sysconfdir}/i2pd/tunnels.conf
%{_sysconfdir}/i2pd/tunnels.conf.d/README

%changelog
* Fri Mar 22 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.24.0:
  * Support of transient keys for LeaseSet2
  * Support of encrypted LeaseSet2
  * Recognize signature type 11 (RedDSA)
  * Support websocket connections over HTTP proxy
  * Ability to disable full addressbook persist
  * Don't load peer profiles if non-persistant
  * REUSE_ADDR for ipv6 acceptors
  * Reset eTags if addressbook can't be loaded
  * Build with boost 1.70
  * Filter out unspecified addresses from RouterInfo
  * Check floodfill status change
  * Correct SAM response for invalid key
  * SAM crash on termination for Windows
  * Race condition for publishing
  * Standard LeaseSet2 support
  * Ability to adjust timestamps through the NTP
  * Ability to disable peer profile persist
  * Request permission for android >= 6
  * Initial addressbook to android assets
  * Cancel graceful shutdown for android
  * Russian translation for android
  * Chacha20 and Poly1305 implementation
  * Eliminate extra copy of NTCP2 send buffers
  * Extract content of tunnel.d from assets on android
  * Removed name resolvers from transports
  * Update reseed certificates
  * LeaseSet published content verification
  * Exclude invalid LeaseSets from the list on a floodfill
  * Build for OpenWrt with openssl 1.1.1
* Fri Nov  9 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.22.0:
  * Multiple tunnel config files from tunnels.d folder
  * Fetch own RouterInfo upon SessionRequest for NTCP2
  * Faster XOR between AES blocks for non AVX capable CPUs
  * Fixed NTCP2 termination send
* Wed Oct 24 2018 Alexei Podvalsky <avvissu@yandex.by>
- Drop i2pd-2.17.0-libs.patch
* Tue Oct 23 2018 Jan Engelhardt <jengelh@inai.de>
- Trim filler word from descriptions and update grammar.
* Tue Oct 23 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.21.1:
  * Handle I2NP messages longer than 32K
  * cost=13 for unpublished NTCP2 address
* Fri Oct  5 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.21.0:
  * Use EdDSA, x25519 and SipHash from openssl 1.1.1 if available
  * NTCP2 ipv6 incoming connections
  * Bandwidth classes 'P' and 'X' without 'O'
  * Support android api > 26
  * Update own RouterInfo if no SSU
  * Fixed NTCP address disappears if NTCP2 enabled
  * Show total number of destination's outgoing tags in the web
    console
* Fri Aug 24 2018 avvissu@yandex.by
- Update to 2.20.0:
  * Full implementation of NTCP2
  * Provide assets for android
  * Some fix in web console
* Wed Jun 27 2018 avvissu@yandex.by
- Update to 2.19.0:
  * ECIES support for RouterInfo
  * HTTP outproxy authentication
  * AVX/AESNI runtime detection
  * Android build using gradle
  * Implementation of I2CP reconfigure
  * EdDSA for RouterInfo by default
  * Datagrams to websocks
  * Fixed tunnels reload
  * Fixed headers in webconsole
  * Correct SAM session name
  * Updated docker
  * Multiple changes for QT GUI
  * Initial implementation of NTCP2
  * Added I2PControl method "ClientServicesInfo"
- Update i2pd-2.17.0-apparmor.patch > i2pd-2.19.0-apparmor.patch
* Wed Jan 31 2018 avvissu@yandex.by
- Update to 2.18.0:
  * Graceful shutdown as soon as no more transit tunnels
  * Show tunnel nicknames for I2CP destination in WebUI
  * Re-create HTTP and SOCKS proxy and shared local destination by tunnel reload
  * Fixed issues and timing for addressbook requests
  * Return correct code if pid file can't be created
  * Fixed build errors with boost 1.66
  * Use transient local destination by default if not specified
  * Check LeaseSet's signature before update
  * Fixed few race conditions for SAM
- Drop i2pd-2.17.0-boost-1.66.patch (fixed))
* Thu Jan 18 2018 avvissu@yandex.by
- Rename the macros: USER > sysuser; GROUP > sysgroup
* Sat Jan 13 2018 avvissu@yandex.by
- Fix build with boost >= 1.66 (i2pd-2.17.0-boost-1.66.patch)
* Wed Dec  6 2017 avvissu@yandex.by
- Initial package
